function [ E ] = Emission( Z, C, sigma )
    % En entrée:
    %   Z: une seule ligne de l'observation
    %   C: Centre des clusters de la base d'apprentisage
    %   Sigma: Variance de la base d'apprentissage
    
    [k, PCA]=size(C);
    % k: Nombre de clusters
    % PCA: niveau de l'optimisation
    
    E=zeros(k,1);
    for i=1:k % pour chaque cluster, une valeur
        e=0;
        for j=1:PCA
            e=e+((Z(j)-C(i,j))^2/sigma(i,j));
        end
        E(i)=exp(-e/2); % Emission pour un cluster
    end
end

